==> wpvulnerability-2.0.0.zip: wpvulnerability/wpvulnerability-notifications.php <==
<?php
/**
 * Notifications functions
 *
 * @package WPVulnerability
 *
 * @version 2.0.0
 */
defined( 'ABSPATH' ) || die( 'No script kiddies please!' );

/**
 * Adds a custom schedule for weekly cron job.
 *
 * @since 2.0.0
 *
 * @param array $schedules The system schedules.
 *
 * @return array The updated list of schedules.
 */
function wpvulnerability_add_every_week( $schedules ) {

	// Add a weekly schedule interval of 604800 seconds (1 week).
	$schedules['weekly'] = array(
		'interval' => 604800,
		'display' => __( 'Every week', 'wpvulnerability' ),
	);

	// Return the modified list of schedules.
	return $schedules;

}

// Hook into the 'cron_schedules' filter to add custom schedule.
add_filter( 'cron_schedules', 'wpvulnerability_add_every_week' );

/**
 * Add a custom schedule for daily events.
 *
 * @since 2.0.0
 *
 * @param array $schedules List of available schedules.
 *
 * @return array Modified list of available schedules.
 */
function wpvulnerability_add_every_day( $schedules ) {

	// Define a new schedule with a 24 hour interval.
	$schedules['daily'] = array(
		'interval' => 86400,
		'display' => __( 'Every day', 'wpvulnerability' ),
	);

	// Return the modified list of schedules.
	return $schedules;

}
// Hook the function to the 'cron_schedules' filter.
add_filter( 'cron_schedules', 'wpvulnerability_add_every_day' );

/**
 * Prepares the HTML email message
 *
 * @since 2.0.0
 *
 * @param string $title The title of the email message.
 * @param string $content The content of the email message.
 * 
 * @return string The prepared HTML email message.
 */

function wpvulnerability_email_prepare( $title, $content ) {

	$message = '';
	$message .= '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">' . "\n";
	$message .= '<html xmlns="http://www.w3.org/1999/xhtml" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '<head>' . "\n";
	$message .= '	<meta name="viewport" content="width=device-width">' . "\n";
	$message .= '	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">' . "\n";
	$message .= '	<title>WPVulnerability</title>' . "\n";
	$message .= '	<style type="text/css">' . "\n";
	$message .= '	img { max-width: 100%; }' . "\n";
	$message .= '  body { -webkit-font-smoothing: antialiased; -webkit-text-size-adjust: none; width: 100% !important; height: 100%; line-height: 1.2em; }' . "\n";
	$message .= '  body { background-color: #f6f6f6; }' . "\n";
	$message .= '  @media only screen and (max-width: 640px) {' . "\n";
	$message .= '		body { padding: 0 !important; }' . "\n";
	$message .= '		h1 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h2 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h3 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h4 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		.container { padding: 0 !important; width: 100% !important; }' . "\n";
	$message .= '		.content { padding: 0 !important; }' . "\n";
	$message .= '		.content-wrap { padding: 10px !important; }' . "\n";
	$message .= '		.invoice { width: 100% !important; }' . "\n";
	$message .= '  }' . "\n";
	$message .= '  </style>' . "\n";
	$message .= '</head>' . "\n";
	$message .= '<body itemscope itemtype="http://schema.org/EmailMessage" style="box-sizing: border-box; -webkit-font-smoothing: antialiased; -webkit-text-size-adjust: none; width: 100% !important; height: 100%; line-height: 1.6em; background-color: #f6f6f6; margin: 0;" bgcolor="#f6f6f6">' . "\n";
	$message .= '	<table class="body-wrap" style="box-sizing: border-box; width: 100%; background-color: #f6f6f6; margin: 0;" bgcolor="#f6f6f6">' . "\n";
	$message .= '		<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '			<td style="box-sizing: border-box; vertical-align: top; margin: 0;" valign="top"></td>' . "\n";
	$message .= '			<td class="container" width="600" style="box-sizing: border-box; vertical-align: top; display: block !important; max-width: 600px !important; clear: both !important; margin: 0 auto;" valign="top">' . "\n";
	$message .= '				<div class="content" style="box-sizing: border-box; max-width: 600px; display: block; margin: 0 auto; padding: 20px;">' . "\n";
	$message .= '					<table class="main" width="100%" cellpadding="0" cellspacing="0" style="box-sizing: border-box; border-radius: 3px; background-color: #fff; margin: 0; border: 1px solid #e9e9e9;" bgcolor="#fff">' . "\n";
	$message .= '						<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '							<td class="content-wrap aligncenter" style="box-sizing: border-box; vertical-align: top; text-align: center; margin: 0; padding: 20px;" align="center" valign="top">' . "\n";
	$message .= '								<table width="100%" cellpadding="0" cellspacing="0" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '									<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<td class="content-block" style="box-sizing: border-box; vertical-align: top; margin: 0; padding: 0 0 20px; text-align: center;" valign="top">' . "\n";
	$message .= '											<img class="aligncenter" src="' . WPVULNERABILITY_PLUGIN_URL . 'assets/logo64.png" width="64" height="64" alt="WPVulnerability">' . "\n";
	$message .= '											<h1 class="aligncenter" style="box-sizing: border-box; color: #000; line-height: 1.2em; text-align: center; margin: 40px 0 0;" align="center">' . $title . '</h1>' . "\n";
	$message .= '										</td>' . "\n";
	$message .= '									</tr>' . "\n";
	$message .= '									<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<td class="content-block alignlef" style="box-sizing: border-box; vertical-align: top; text-align: left; margin: 0; padding: 0 0 20px;" valign="top">' . "\n";
	$message .= $content;
	$message .= '									</td>' . "\n";
	$message .= '									</tr>' . "\n";
	$message .= '								</table>' . "\n";
	$message .= '								<div class="footer" style="box-sizing: border-box; width: 100%; clear: both; color: #999; margin: 0; padding: 20px;">' . "\n";
	$message .= '									<table width="100%" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '											<td class="aligncenter content-block" style="box-sizing: border-box; vertical-align: top; color: #999; text-align: center; margin: 0; padding: 0 0 20px;" align="center" valign="top">' . "\n";
	$message .= sprintf(
		// translators: %1$s the website of Database, %2$s database site name.
		__( 'Learn more about the WordPress Vulnerability Database API at <a href="%1$s">%2$s</a>', 'wpvulnerability' ),
		'https://vulnerability.wpsysadmin.com/',
		'WPVulnerability'
	);
	$message .= '											</td>' . "\n";
	$message .= '										</tr>' . "\n";
	$message .= '										<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '											<td class="aligncenter content-block" style="box-sizing: border-box; vertical-align: top; color: #999; text-align: center; margin: 0; padding: 0 0 20px;" align="center" valign="top"><a href="' . site_url() . '" target="_blank" rel="noopener noreferrer">' . site_url() . '</a></td>' . "\n";
	$message .= '										</tr>' . "\n";
	$message .= '									</table>' . "\n";
	$message .= '								</div>' . "\n";
	$message .= '							</td>' . "\n";
	$message .= '							<td style="box-sizing: border-box; vertical-align: top; margin: 0;" valign="top"></td>' . "\n";
	$message .= '						</tr>' . "\n";
	$message .= '					</table>' . "\n";
	$message .= '				</div>' . "\n";
	$message .= '			</td>' . "\n";
	$message .= '		</tr>' . "\n";
	$message .= '	</table>' . "\n";
	$message .= '</body>' . "\n";
	$message .= '</html>';

	// Return the prepared HTML email message.
	return $message;

}

/**
 * Executes the vulnerability notification.
 *
 * @since 2.0.0
 *
 * @return void
 */
function wpvulnerability_execute_notification() {

	$email_content = '';
	$wpvulnerability_settings = get_option( 'wpvulnerability-config' );

	// If email or period settings are empty, return.
	if ( empty( $wpvulnerability_settings['email'] ) || empty( $wpvulnerability_settings['period'] ) ) {
		return;
	}

	// Get HTML for core, plugins, and themes vulnerabilities.
	$html_core = wpvulnerability_html_core();
	$html_plugins = wpvulnerability_html_plugins();
	$html_themes = wpvulnerability_html_themes();
	$html_themes = null;

	// If no vulnerabilities were found, return.
	if ( empty( $html_core ) && empty( $html_plugins) && empty( $html_themes ) ) {
		return;
	}

	// Add core vulnerabilities HTML to email content.
	if ( ! empty( $html_core ) ) {
		$email_content .= '<h2>' . esc_html__( 'Core vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_core;
	}

	// Add plugins vulnerabilities HTML to email content.
	if ( $html_plugins ) {
		$email_content .= '<h2>' . esc_html__( 'Plugins vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_plugins;
	}

	// Add themes vulnerabilities HTML to email content.
	if ( $html_themes ) {
		$email_content .= '<h2>' . esc_html__( 'Themes vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_themes;
	}

	// Prepare email subject and content.
	$email_subject = sprintf(
		// translators: Site name.
		__( 'Vulnerability found: %s', 'wpvulnerability' ),
		get_bloginfo( 'name' )
	);

	$email_prepared = wpvulnerability_email_prepare( esc_html__( 'Vulnerability found', 'wpvulnerability' ), $email_content );

	// Prepare email headers.
	$email_headers = array();
	$email_headers[] = 'From: WPVulnerability <' . get_bloginfo( 'admin_email' ) . '>';
	$email_headers[] = 'Content-Type: text/html; charset=UTF-8';

	// Send email.
	wp_mail( $wpvulnerability_settings['email'], $email_subject, $email_prepared, $email_headers );

}

/**
 * Schedule vulnerability notification and execute notification function.
 *
 * @since 2.0.0
 *
 * @return void
 */
// Get WP Vulnerability settings.
$wpvulnerability_s = get_option( 'wpvulnerability-config' );

// Check if notification period is set.
if ( isset( $wpvulnerability_s['period'] ) ) {

	// Check if notification is not already scheduled.
	if ( ! wp_next_scheduled( 'wpvulnerability_notification' ) ) {

		// Schedule notification.
		wp_schedule_event( time(), $wpvulnerability_s['period'], 'wpvulnerability_notification' );

	}

	// Add action to execute notification function.
	add_action( 'wpvulnerability_notification', 'wpvulnerability_execute_notification' );

}
unset( $wpvulnerability_s );

==> wpvulnerability-2.0.2.zip: wpvulnerability/wpvulnerability-notifications.php <==
<?php
/**
 * Notifications functions
 *
 * @package WPVulnerability
 *
 * @version 2.0.0
 */
defined( 'ABSPATH' ) || die( 'No script kiddies please!' );

/**
 * Adds a custom schedule for weekly cron job.
 *
 * @since 2.0.0
 *
 * @param array $schedules The system schedules.
 *
 * @return array The updated list of schedules.
 */
function wpvulnerability_add_every_week( $schedules ) {

	// Add a weekly schedule interval of 604800 seconds (1 week).
	$schedules['weekly'] = array(
		'interval' => 604800,
		'display' => __( 'Every week', 'wpvulnerability' ),
	);

	// Return the modified list of schedules.
	return $schedules;

}

// Hook into the 'cron_schedules' filter to add custom schedule.
add_filter( 'cron_schedules', 'wpvulnerability_add_every_week' );

/**
 * Add a custom schedule for daily events.
 *
 * @since 2.0.0
 *
 * @param array $schedules List of available schedules.
 *
 * @return array Modified list of available schedules.
 */
function wpvulnerability_add_every_day( $schedules ) {

	// Define a new schedule with a 24 hour interval.
	$schedules['daily'] = array(
		'interval' => 86400,
		'display' => __( 'Every day', 'wpvulnerability' ),
	);

	// Return the modified list of schedules.
	return $schedules;

}
// Hook the function to the 'cron_schedules' filter.
add_filter( 'cron_schedules', 'wpvulnerability_add_every_day' );

/**
 * Prepares the HTML email message
 *
 * @since 2.0.0
 *
 * @param string $title The title of the email message.
 * @param string $content The content of the email message.
 * 
 * @return string The prepared HTML email message.
 */

function wpvulnerability_email_prepare( $title, $content ) {

	$message = '';
	$message .= '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">' . "\n";
	$message .= '<html xmlns="http://www.w3.org/1999/xhtml" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '<head>' . "\n";
	$message .= '	<meta name="viewport" content="width=device-width">' . "\n";
	$message .= '	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">' . "\n";
	$message .= '	<title>WPVulnerability</title>' . "\n";
	$message .= '	<style type="text/css">' . "\n";
	$message .= '	img { max-width: 100%; }' . "\n";
	$message .= '  body { -webkit-font-smoothing: antialiased; -webkit-text-size-adjust: none; width: 100% !important; height: 100%; line-height: 1.2em; }' . "\n";
	$message .= '  body { background-color: #f6f6f6; }' . "\n";
	$message .= '  @media only screen and (max-width: 640px) {' . "\n";
	$message .= '		body { padding: 0 !important; }' . "\n";
	$message .= '		h1 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h2 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h3 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		h4 { margin: 20px 0 5px 0 !important; }' . "\n";
	$message .= '		.container { padding: 0 !important; width: 100% !important; }' . "\n";
	$message .= '		.content { padding: 0 !important; }' . "\n";
	$message .= '		.content-wrap { padding: 10px !important; }' . "\n";
	$message .= '		.invoice { width: 100% !important; }' . "\n";
	$message .= '  }' . "\n";
	$message .= '  </style>' . "\n";
	$message .= '</head>' . "\n";
	$message .= '<body itemscope itemtype="http://schema.org/EmailMessage" style="box-sizing: border-box; -webkit-font-smoothing: antialiased; -webkit-text-size-adjust: none; width: 100% !important; height: 100%; line-height: 1.6em; background-color: #f6f6f6; margin: 0;" bgcolor="#f6f6f6">' . "\n";
	$message .= '	<table class="body-wrap" style="box-sizing: border-box; width: 100%; background-color: #f6f6f6; margin: 0;" bgcolor="#f6f6f6">' . "\n";
	$message .= '		<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '			<td style="box-sizing: border-box; vertical-align: top; margin: 0;" valign="top"></td>' . "\n";
	$message .= '			<td class="container" width="600" style="box-sizing: border-box; vertical-align: top; display: block !important; max-width: 600px !important; clear: both !important; margin: 0 auto;" valign="top">' . "\n";
	$message .= '				<div class="content" style="box-sizing: border-box; max-width: 600px; display: block; margin: 0 auto; padding: 20px;">' . "\n";
	$message .= '					<table class="main" width="100%" cellpadding="0" cellspacing="0" style="box-sizing: border-box; border-radius: 3px; background-color: #fff; margin: 0; border: 1px solid #e9e9e9;" bgcolor="#fff">' . "\n";
	$message .= '						<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '							<td class="content-wrap aligncenter" style="box-sizing: border-box; vertical-align: top; text-align: center; margin: 0; padding: 20px;" align="center" valign="top">' . "\n";
	$message .= '								<table width="100%" cellpadding="0" cellspacing="0" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '									<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<td class="content-block" style="box-sizing: border-box; vertical-align: top; margin: 0; padding: 0 0 20px; text-align: center;" valign="top">' . "\n";
	$message .= '											<img class="aligncenter" src="' . WPVULNERABILITY_PLUGIN_URL . 'assets/logo64.png" width="64" height="64" alt="WPVulnerability">' . "\n";
	$message .= '											<h1 class="aligncenter" style="box-sizing: border-box; color: #000; line-height: 1.2em; text-align: center; margin: 40px 0 0;" align="center">' . $title . '</h1>' . "\n";
	$message .= '											<p class="aligncenter" style="box-sizing: border-box; color: #000; line-height: 1.2em; text-align: center; margin: 5px 0 0;" align="center"><a href="' . site_url() . '" target="_blank" rel="noopener noreferrer">' . site_url() . '</a></p>' . "\n";
	$message .= '										</td>' . "\n";
	$message .= '									</tr>' . "\n";
	$message .= '									<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<td class="content-block alignlef" style="box-sizing: border-box; vertical-align: top; text-align: left; margin: 0; padding: 0 0 20px;" valign="top">' . "\n";
	$message .= $content;
	$message .= '									</td>' . "\n";
	$message .= '									</tr>' . "\n";
	$message .= '								</table>' . "\n";
	$message .= '								<div class="footer" style="box-sizing: border-box; width: 100%; clear: both; color: #999; margin: 0; padding: 20px;">' . "\n";
	$message .= '									<table width="100%" style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '										<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '											<td class="aligncenter content-block" style="box-sizing: border-box; vertical-align: top; color: #999; text-align: center; margin: 0; padding: 0 0 20px;" align="center" valign="top">' . "\n";
	$message .= sprintf(
		// translators: %1$s the website of Database, %2$s database site name.
		__( 'Learn more about the WordPress Vulnerability Database API at <a href="%1$s">%2$s</a>', 'wpvulnerability' ),
		'https://vulnerability.wpsysadmin.com/',
		'WPVulnerability'
	);
	$message .= '											</td>' . "\n";
	$message .= '										</tr>' . "\n";
	$message .= '										<tr style="box-sizing: border-box; margin: 0;">' . "\n";
	$message .= '											<td class="aligncenter content-block" style="box-sizing: border-box; vertical-align: top; color: #999; text-align: center; margin: 0; padding: 0 0 20px;" align="center" valign="top"><a href="' . site_url() . '" target="_blank" rel="noopener noreferrer">' . site_url() . '</a></td>' . "\n";
	$message .= '										</tr>' . "\n";
	$message .= '									</table>' . "\n";
	$message .= '								</div>' . "\n";
	$message .= '							</td>' . "\n";
	$message .= '							<td style="box-sizing: border-box; vertical-align: top; margin: 0;" valign="top"></td>' . "\n";
	$message .= '						</tr>' . "\n";
	$message .= '					</table>' . "\n";
	$message .= '				</div>' . "\n";
	$message .= '			</td>' . "\n";
	$message .= '		</tr>' . "\n";
	$message .= '	</table>' . "\n";
	$message .= '</body>' . "\n";
	$message .= '</html>';

	// Return the prepared HTML email message.
	return $message;

}

/**
 * Executes the vulnerability notification.
 *
 * @since 2.0.0
 *
 * @return void
 */
function wpvulnerability_execute_notification() {

	$email_content = '';
	$wpvulnerability_settings = get_option( 'wpvulnerability-config' );

	// If email or period settings are empty, return.
	if ( !isset( $wpvulnerability_settings['emails'] ) || !isset( $wpvulnerability_settings['period'] ) ) {
		return;
	}
	if ( !$wpvulnerability_settings['emails'] || !$wpvulnerability_settings['period'] ) {
		return;
	}

	// Get HTML for core, plugins, and themes vulnerabilities.
	$html_core = null;
	if ( json_decode( get_option( 'wpvulnerability-core-vulnerable' ) ) ) {
		$html_core = wpvulnerability_html_core();
	}

	$html_plugins = null;
	if ( json_decode( get_option( 'wpvulnerability-plugins-vulnerable' ) ) ) {
		$html_plugins = wpvulnerability_html_plugins();
	}

	$html_themes = null;
	if ( json_decode( get_option( 'wpvulnerability-themes-vulnerable' ) ) ) {
		$html_themes = wpvulnerability_html_themes();
	}

	// If no vulnerabilities were found, return.
	if ( empty( $html_core ) && empty( $html_plugins) && empty( $html_themes ) ) {
		return;
	}

	// Add core vulnerabilities HTML to email content.
	if ( ! empty( $html_core ) ) {
		$email_content .= '<h2>' . esc_html__( 'Core vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_core;
	}

	// Add plugins vulnerabilities HTML to email content.
	if ( $html_plugins ) {
		$email_content .= '<h2>' . esc_html__( 'Plugins vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_plugins;
	}

	// Add themes vulnerabilities HTML to email content.
	if ( $html_themes ) {
		$email_content .= '<h2>' . esc_html__( 'Themes vulnerabilities', 'wpvulnerability' ) . '</h2>';
		$email_content .= $html_themes;
	}

	// Prepare email subject and content.
	$email_subject = sprintf(
		// translators: Site name.
		__( 'Vulnerability found: %s', 'wpvulnerability' ),
		get_bloginfo( 'name' )
	);

	$email_prepared = wpvulnerability_email_prepare( esc_html__( 'Vulnerability found', 'wpvulnerability' ), $email_content );

	// Prepare email headers.
	$email_headers = array();
	$email_headers[] = 'From: WPVulnerability <' . get_bloginfo( 'admin_email' ) . '>';
	$email_headers[] = 'Content-Type: text/html; charset=UTF-8';

	// Send email.
	wp_mail( $wpvulnerability_settings['emails'], $email_subject, $email_prepared, $email_headers );

}

/**
 * Schedule vulnerability notification and execute notification function.
 *
 * @since 2.0.0
 *
 * @return void
 */
// Get WP Vulnerability settings.
$wpvulnerability_s = get_option( 'wpvulnerability-config' );

// Check if notification period is set.
if ( isset( $wpvulnerability_s['period'] ) ) {

	// Check if notification is not already scheduled.
	if ( ! wp_next_scheduled( 'wpvulnerability_notification' ) ) {

		// Schedule notification.
		wp_schedule_event( time(), $wpvulnerability_s['period'], 'wpvulnerability_notification' );

	}

	// Add action to execute notification function.
	add_action( 'wpvulnerability_notification', 'wpvulnerability_execute_notification' );

}
unset( $wpvulnerability_s );
